@@ -110,9 +110,9 @@ COMMANDS = {
     "ipv4-restore": "/usr/bin/iptables-restore",
     "ipv6":         "/usr/bin/ip6tables",
     "ipv6-restore": "/usr/bin/ip6tables-restore",
-    "eb":           "/usr/bin/ebtables",
-    "eb-restore":   "/usr/bin/ebtables-restore",
-    "ipset":        "/usr/bin/ipset",
+    "eb":           "/bin/false",
+    "eb-restore":   "/bin/false",
+    "ipset":        "/bin/false",
     "modprobe":     "/usr/bin/modprobe",
     "rmmod":        "/usr/bin/rmmod",
 }
